@@ -31,6 +31,9 @@ from configparser import ConfigParser, NoSectionError, NoOptionError
 
 # pylint: disable=wildcard-import,unused-wildcard-import
 from qt import *
+from qtpy import QT5, QT6, PYSIDE2, PYSIDE6, QT_VERSION, API_NAME, PYQT_VERSION
+if QT6:
+    from qtpy.QtCore import QKeyCombination
 
 from mi18n import MLocale, KDETranslator, i18n, i18nc
 
@@ -90,6 +93,15 @@ class KApplication(QApplication):
                 QLibraryInfo.location(QLibraryInfo.TranslationsPath), 'qtbase_{}.qm'.format(language)))
             self.installTranslatorFile('/usr/share/locale/{}/LC_MESSAGES/kwidgetsaddons5_qt.qm'.format(language))
 
+    @classmethod
+    def desktopSize(cls) -> QSize:
+        """The size of the current screen"""
+        try:
+            result = Internal.app.desktop().availableGeometry()
+        except AttributeError:
+            result = Internal.mainWindow.screen().availableGeometry()
+        return result
+
 
 class CaptionMixin:
 
@@ -193,7 +205,7 @@ class KMessageBox:
             messageLabel.setOpenExternalLinks(True)
         messageLabel.setTextInteractionFlags(flags)
 
-        desktop = Internal.app.desktop().availableGeometry()
+        desktop = KApplication.desktopSize()
         if messageLabel.sizeHint().width() > desktop.width() * 0.5:
             messageLabel.setWordWrap(True)
 
@@ -232,10 +244,8 @@ class KDialog(CaptionMixin, QDialog):
     Default = QDialogButtonBox.RestoreDefaults
     Close = QDialogButtonBox.Close
 
-    def __init__(self, parent=None, flags=None):
-        if flags is None:
-            flags = Qt.WindowFlags(0)
-        QDialog.__init__(self, parent, flags)
+    def __init__(self, parent=None):
+        QDialog.__init__(self, parent)
         self.buttonBox = QDialogButtonBox()
         self.buttonBox.accepted.connect(self.accept)
         self.buttonBox.rejected.connect(self.reject)
@@ -468,7 +478,7 @@ class KXmlGuiWindow(CaptionMixin, QMainWindow):
         self.toolBar().setVisible(Internal.Preferences.toolBarVisible)
         self.actionStatusBar.setChecked(self.statusBar().isVisible())
         self.actionToolBar.setChecked(self.toolBar().isVisible())
-        self.actionFullscreen.setChecked(self.windowState() & Qt.WindowFullScreen)
+        self.actionFullscreen.setChecked(self.windowState() & Qt.WindowFullScreen == Qt.WindowFullScreen)
         QMainWindow.showEvent(self, event)
 
     def hideEvent(self, event):
@@ -649,7 +659,10 @@ class Action(QAction):
         if parent:
             parent.actionCollection().addAction(name, self)
         if shortcut:
-            self.setShortcut(Qt.CTRL + shortcut)
+            if QT6:
+                if isinstance(shortcut, QKeyCombination):
+                    shortcut = shortcut.key()
+            self.setShortcut(QKeySequence(shortcut | Qt.CTRL))
             self.setShortcutContext(Qt.ApplicationShortcut)
         if actionData is not None:
             self.setData(actionData)
@@ -989,16 +1002,17 @@ class AboutKajonggDialog(KDialog):
         except ImportError:
             VERSION = "Unknown"
 
-        if os.environ['QT_API'].startswith('pyqt'):
-            # pylint: disable=no-name-in-module
-            from PyQt5.sip import SIP_VERSION_STR
-            from PyQt5.QtCore import PYQT_VERSION_STR
-            from PyQt5.QtCore import QT_VERSION_STR
-            qtVersion = 'Qt {} with PyQt5 {} sip {}'.format(QT_VERSION_STR, PYQT_VERSION_STR, SIP_VERSION_STR)
-        else:
-            import PySide2 as PySide
-            qtVersion = 'Qt {} with Pyside2 {} compiled with Qt {}'.format(
-                PySide.QtCore.qVersion(), PySide.__version__, PySide.QtCore.__version__)
+        underVersions = ['Qt' + QT_VERSION +' API=' + API_NAME]
+        if PYQT_VERSION:
+            from sip import SIP_VERSION_STR
+            underVersions.append('sip ' + SIP_VERSION_STR)
+        if PYSIDE2:
+            import PySide2  # pylint: disable=import-error
+            underVersions.append('PySide2 ' + PySide2.__version__)
+        if PYSIDE6:
+            import PySide6  # pylint: disable=import-error
+            underVersions.append('PySide6 ' + PySide6.__version__)
+
 
         h1vLayout.addWidget(QLabel(i18n('Version: %1', VERSION)))
         h1vLayout.addWidget(QLabel(i18n('Protocol version %1', Internal.defaultPort)))
@@ -1006,14 +1020,12 @@ class AboutKajonggDialog(KDialog):
             "Wolfgang Rohdewald",
             i18n("Original author"),
             "wolfgang@rohdewald.de"), )
-        underVersions = []
         try:
             versions = popenReadlines('kf5-config -v')
             versionsDict = dict(x.split(': ') for x in versions if ':' in x)
             underVersions.append('KDE Frameworks %s' % versionsDict['KDE Frameworks'])
         except OSError:
             underVersions.append(i18n('KDE Frameworks (not installed or not usable)'))
-        underVersions.append(qtVersion)
         underVersions.append('Twisted %s' % __version__)
         underVersions.append(
             'Python {}.{}.{} {}'.format(*sys.version_info[:5]))
@@ -1023,7 +1035,6 @@ class AboutKajonggDialog(KDialog):
                       'Using versions %1',
                       ', '.join(
                           underVersions))))
-        h1vLayout.addWidget(QLabel(i18n('Not using broken Python KDE bindings')))
         hLayout1.addLayout(h1vLayout)
         spacerItem = QSpacerItem(
             20,
@@ -1047,7 +1058,7 @@ class AboutKajonggDialog(KDialog):
                      "use the application kmahjongg."),
                 "(C) 2008-2017 Wolfgang Rohdewald",
                 '<a href="{link}">{link}</a>'.format(
-                    link='http://kde.org/applications/games/kajongg/')]))
+                    link='https://apps.kde.org/kajongg')]))
         licenseLabel = QLabel()
         licenseLabel.setText(
             '<a href="file://{link}">GNU General Public License Version 2</a>'.format(
